@@ -4,8 +4,8 @@ import time
 
 def snake_to_camel(name):
     # Conditional clauses to support edge-cases where camelCase not strictly followed by Zscaler
-    if name == 'routable_ip':
-        return 'routableIP'
+    if name == "routable_ip":
+        return "routableIP"
     else:
         name = name[0].lower() + name.title()[1:].replace("_", "")
     return name
@@ -21,4 +21,4 @@ def obfuscate_api_key(seed):
     for j in range(0, len(str(r)), 1):
         key += seed[int(str(r)[j]) + 2]
 
-    return {'timestamp': now, 'key': key}
\ No newline at end of file
+    return {"timestamp": now, "key": key}
