@@ -3,25 +3,25 @@ from restfly.endpoint import APIEndpoint
 
 class ConnectorGroupsAPI(APIEndpoint):
 
-    def list(self):
+    def list_groups(self):
         """
-        Provides a list of all connector groups.
+        Returns a list of all connector groups.
 
         Returns:
             :obj:`list`: List of all configured connector groups.
 
         Examples:
-            >>> connector_groups = zpa.connector_groups.list()
+            >>> connector_groups = zpa.connector_groups.list_groups()
 
         """
         return self._get('appConnectorGroup').list
 
-    def details(self, id: str):
+    def get_group(self, group_id: str):
         """
         Get information for a specified connector group.
 
         Args:
-            id (str):
+            group_id (str):
                 The unique identifier for the connector group.
 
         Returns:
@@ -29,7 +29,7 @@ class ConnectorGroupsAPI(APIEndpoint):
                 The connector group resource record.
 
         Examples:
-            >>> connector_group = zpa.connector_groups.details('2342342354545455')
+            >>> connector_group = zpa.connector_groups.get_group('2342342354545455')
 
         """
-        return self._get(f'appConnectorGroup/{id}')
+        return self._get(f'appConnectorGroup/{group_id}')
